pugbot_ng
=========

pugbot-ng = pugbot next gen

Commands:

* ``help``
* ``plzdie``
* ``join`` or ``join <mapname>``
* ``leave``
* ``status``
* ``maps``
* ``vote <mapname>``
* ``votes``

Discussion
----------

Please report bugs using `GitHub Issues`_.

You can also join ``#pugbot-ng`` on `Quakenet`_ to ask questions or get involved.

.. _`GitHub Issues`: https://github.com/clearskies/pugbot_ng/issues
.. _`Quakenet`: https://www.quakenet.org/
